@@ -249,9 +249,10 @@ def check_syntax(name, config):
             r = min(r, check_stream_config(name, "iv", stream_config["iv"]))
             r = min(r, check_stream_config(name, "prep",
                                            stream_config["prep"], allow_no_keep=False))
-            # add a sensor stream with no keep
-            stream_config["sensor"] = {"keep": '1w',
-                                       "decimate": True}
+            if "sensor" not in stream_config:
+                # add sensor stream with no keep
+                stream_config["sensor"] = {"keep": False, "decimate": False}
+            r = min(r, check_stream_config(name, "sensor", stream_config["sensor"]))
             if(r != Status.ok):
                 return Status.error  # check_stream_config prints the error message
             my_status = min(my_status, r)
