@@ -1,5 +1,4 @@
 from enum import IntEnum
-import logging
 
 
 HELP_URL = "http://nilm.standalone/help/"
@@ -16,10 +15,11 @@ COL_BLUE = ESC_SEQ+"34;01m"
 COL_MAGENTA = ESC_SEQ+"35;01m"
 COL_CYAN = ESC_SEQ+"36;01m"
 
+
 def print_error(msg, url=""):
-    logging.error("["+COL_RED+"ERROR"+COL_RESET+"]: %s" % msg)
+    print("["+COL_RED+"ERROR"+COL_RESET+"]: %s" % msg)
     if(url != ""):
-        logging.error("\tsee [%s] for help" % (HELP_URL + url))
+        print("\tsee [%s] for help" % (HELP_URL + url))
 
 # Print formatted warning message
 #  If a url is provided print this too
@@ -27,9 +27,9 @@ def print_error(msg, url=""):
 
 
 def print_warning(msg, url=""):
-    logging.warning("["+COL_YELLOW+"WARN"+COL_RESET+"]: %s" % msg)
+    print("["+COL_YELLOW+"WARN"+COL_RESET+"]: %s" % msg)
     if(url != ""):
-        logging.warn("\tsee [%s] for help" % (HELP_URL + url))
+        print("\tsee [%s] for help" % (HELP_URL + url))
 
 
 class Status(IntEnum):
